body {
    box-sizing: border-box;
    color: #384359;
    margin: 0;
    padding: 0;
    width: 100%;
    height: 100%;
    background: #D9D9D9;
}

.container {
    height: 100%;
}

a {
    color: #D9D9D9;
    text-decoration: none;
}

ul {
    list-style: none;
    padding: 0;
}

.main_content {
    position: relative;
    width: 100%;
    height: 100%;
    -webkit-transform: translate(200px, 0);
    -moz-transform: translate(200px, 0);
    -ms-transform: translate(200px, 0);
    -o-transform: translate(200px, 0);
    transform: translate(200px, 0);
}

.main_content h1 {
    text-align: center;
    background: #88ABF2;
    width: 90%;
    margin: 0;
}

.main_content .model_data {
    padding: 0 10px;
}

.main_content .model_data ul {
    margin-left: 20px;
}

.first_level_title {
    font-size: 22px;
}

.second_level_title {
    font-size: 18px;
}

.third_level_title {
    font-size: 14px;
}

.fourth_level_title {
    font-size: 12px;
}

.first_level_title, .second_level_title, .third_level_title, .fourth_level_title {
    font-weight: bold;
}

.first_level_text, .second_level_text, .third_level_text, .fourth_level_text {
    font-family: Incosolata, monospace;
}

.first_level_text {
    font-size: 18px;
}

.second_level_text {
    font-size: 16px;
}

.third_level_text {
    font-size: 12px;
}

.fourth_level_text {
    font-size: 10px;
}

.left-nav {
    position: fixed;
    left: 0;
    top: 0;
    padding: 0 10px;
    width: 180px;
    height: 100%;
    background: #4F5E8C;
    color: #A5A5A5;
}

.left-nav .logo {
    text-align: center;
    padding: 20px 0;
}

.left-nav .nav_title {
    margin-top: 10px;
    font-weight: bold;
}

.left-nav ul ul {
    margin-left: 10px;
}