# -*- coding: utf-8 -*-
from __future__ import unicode_literals

"""django-audit-tools"""
__version__ = '0.4.0'
__license__ = 'GNU GPL v2'

__author__ = 'José Antonio Perdiguero López'
__email__ = 'perdy.hh@gmail.com'

__url__ = 'https://github.com/PeRDy/django-audit-tools'
__description__ = 'Django application that provides a set of tools for auditing requests and models and improve logging'

default_app_config = 'audit_tools.apps.AuditToolsApp'
